@@ -1,4 +1,5 @@
 test_that("working example", {
+  skip_on_cran()
   db <- DBI::dbConnect(duckdb::duckdb(), ":memory:")
   cohort <- dplyr::tibble(
     cohort_definition_id = c(1,1,1),
@@ -44,7 +45,7 @@ test_that("working example", {
   )
 
   # test name argument works
-  cdm$cohort2 <- cdm$cohort1 %>%
+  cdm$cohort2 <- cdm$cohort1 |>
     addCohortSurvival(
       cdm = cdm,
       outcomeCohortTable = "cohort1",
@@ -52,7 +53,7 @@ test_that("working example", {
       name = "cohort2"
     )
 
-  cdm$cohort1 <- cdm$cohort1 %>%
+  cdm$cohort1 <- cdm$cohort1 |>
     addCohortSurvival(
       cdm = cdm,
       outcomeCohortTable = "cohort1",
@@ -81,70 +82,70 @@ test_that("another working example", {
   cdm <- CDMConnector::cdmFromCon(con, cdmSchema = "main", writeSchema = "main")
 
   celecoxibCodes <- CodelistGenerator::getDescendants(cdm, conceptId = 1118084)
-  cdm$celecoxib <- cdm$drug_exposure %>%
+  cdm$celecoxib <- cdm$drug_exposure |>
     dplyr::inner_join(
-      celecoxibCodes %>%
+      celecoxibCodes |>
         dplyr::select(concept_id),
       by = c("drug_concept_id" = "concept_id"),
       copy = TRUE
-    ) %>%
-    PatientProfiles::addDemographics(indexDate = "drug_exposure_start_date") %>%
+    ) |>
+    PatientProfiles::addDemographics(indexDate = "drug_exposure_start_date") |>
     dplyr::filter(!is.na(prior_observation) &
-                    prior_observation>=0 ) %>%
+                    prior_observation>=0 ) |>
     dplyr::rename(
       "subject_id" = "person_id",
       "cohort_start_date" = "drug_exposure_start_date"
-    ) %>%
+    ) |>
     dplyr::mutate(cohort_definition_id = 1L,
-                  cohort_end_date = .data$cohort_start_date) %>%
+                  cohort_end_date = .data$cohort_start_date) |>
     dplyr::select(
       "cohort_definition_id", "subject_id",
       "cohort_start_date", "cohort_end_date"
-    ) %>%
+    ) |>
     dplyr::compute(name = "celecoxib",
                    temporary = FALSE)
 
-  celecoxib_set <- cdm$celecoxib %>%
-    dplyr::select("cohort_definition_id") %>%
-    dplyr::distinct() %>%
-    dplyr::mutate(cohort_name = "celecoxib") %>%
+  celecoxib_set <- cdm$celecoxib |>
+    dplyr::select("cohort_definition_id") |>
+    dplyr::distinct() |>
+    dplyr::mutate(cohort_name = "celecoxib") |>
     dplyr::collect()
 
-  cdm$celecoxib <- cdm$celecoxib %>%
+  cdm$celecoxib <- cdm$celecoxib |>
     omopgenerics::newCohortTable(cohortSetRef =  celecoxib_set)
 
 
   GiBleedCodes <- CodelistGenerator::getDescendants(cdm, conceptId = 192671)
-  cdm$gi_bleed <- cdm$condition_occurrence %>%
+  cdm$gi_bleed <- cdm$condition_occurrence |>
     dplyr::inner_join(
-      GiBleedCodes %>%
+      GiBleedCodes |>
         dplyr::select(concept_id),
       by = c("condition_concept_id" = "concept_id"),
       copy = TRUE
-    ) %>%
+    ) |>
     dplyr::rename(
       "subject_id" = "person_id",
       "cohort_start_date" = "condition_start_date"
-    ) %>%
-    dplyr::mutate(cohort_end_date = cohort_start_date) %>%
-    dplyr::mutate(cohort_definition_id = 1L) %>%
+    ) |>
+    dplyr::mutate(cohort_end_date = cohort_start_date) |>
+    dplyr::mutate(cohort_definition_id = 1L) |>
     dplyr::select(
       "cohort_definition_id", "subject_id",
       "cohort_start_date", "cohort_end_date"
-    ) %>%
+    ) |>
     dplyr::compute(temporary = FALSE,
                    name = "gi_bleed")
-  gi_bleed_set <- cdm$gi_bleed %>%
-    dplyr::select("cohort_definition_id") %>%
-    dplyr::distinct() %>%
-    dplyr::mutate(cohort_name = "gi_bleed") %>%
+  gi_bleed_set <- cdm$gi_bleed |>
+    dplyr::select("cohort_definition_id") |>
+    dplyr::distinct() |>
+    dplyr::mutate(cohort_name = "gi_bleed") |>
     dplyr::collect()
 
-  cdm$gi_bleed <- cdm$gi_bleed %>%
+  cdm$gi_bleed <- cdm$gi_bleed |>
     omopgenerics::newCohortTable(cohortSetRef = gi_bleed_set)
 
-  cdm$celecoxib <- cdm$celecoxib %>%
-    PatientProfiles::addAge() %>%
+  cdm$celecoxib <- cdm$celecoxib |>
+    PatientProfiles::addAge() |>
     addCohortSurvival(
       cdm = cdm,
       outcomeCohortTable = "gi_bleed"
@@ -212,48 +213,42 @@ test_that("censorOnCohortExit", {
     cdmName = "mock_es"
   )
 
-  cohortNoCensorExit <- cdm$cohort1 %>%
+  cohortNoCensorExit <- cdm$cohort1 |>
     addCohortSurvival(
       cdm = cdm,
       outcomeCohortTable = "cohort2",
       outcomeCohortId = 1
-    ) %>%
+    ) |>
     dplyr::arrange(subject_id)
-  cohortCensorExit <- cdm$cohort1 %>%
+  cohortCensorExit <- cdm$cohort1 |>
     addCohortSurvival(
       cdm = cdm,
       outcomeCohortTable = "cohort2",
       outcomeCohortId = 1,
       censorOnCohortExit = TRUE
-    ) %>%
+    ) |>
     dplyr::arrange(subject_id)
 
-  compareNA <- function(v1, v2) {
-    same <- (v1 == v2) | (is.na(v1) & is.na(v2))
-    same[is.na(same)] <- FALSE
-    return(same)
-  }
-
-  expect_true(all(compareNA(cohortNoCensorExit %>%
-                              dplyr::select(status) %>%
+  expect_true(all(compareNA(cohortNoCensorExit |>
+                              dplyr::select(status) |>
                               dplyr::pull(),
-                            cohortCensorExit %>%
-                              dplyr::select(status) %>%
+                            cohortCensorExit |>
+                              dplyr::select(status) |>
                               dplyr::pull())))
-  expect_true(all(compareNA(sort(cohortNoCensorExit %>%
-                                   dplyr::select(time) %>%
+  expect_true(all(compareNA(sort(cohortNoCensorExit |>
+                                   dplyr::select(time) |>
                                    dplyr::pull()),
                             sort(c(NA, 3, 1155)))))
-  expect_true(all(compareNA(sort(cohortNoCensorExit %>%
-                                   dplyr::select(days_to_exit) %>%
+  expect_true(all(compareNA(sort(cohortNoCensorExit |>
+                                   dplyr::select(days_to_exit) |>
                                    dplyr::pull()),
                             sort(c(1186, 1216, 1155)))))
-  expect_true(all(compareNA(sort(cohortCensorExit %>%
-                                   dplyr::select(time) %>%
+  expect_true(all(compareNA(sort(cohortCensorExit |>
+                                   dplyr::select(time) |>
                                    dplyr::pull()),
                             sort(c(NA, 3, 60)))))
-  expect_true(all(compareNA(sort(cohortCensorExit %>%
-                                   dplyr::select(days_to_exit) %>%
+  expect_true(all(compareNA(sort(cohortCensorExit |>
+                                   dplyr::select(days_to_exit) |>
                                    dplyr::pull()),
                             sort(c(91, 213, 60)))))
 
@@ -317,36 +312,30 @@ test_that("censorOnDate", {
     cdmName = "mock_es"
   )
 
-  cohortCensorDate <- cdm$cohort1 %>%
+  cohortCensorDate <- cdm$cohort1 |>
     addCohortSurvival(
       cdm = cdm,
       outcomeCohortTable = "cohort2",
       outcomeCohortId = 1,
       censorOnDate = as.Date("2021-01-04")
-    ) %>%
+    ) |>
     dplyr::arrange(subject_id)
 
-  compareNA <- function(v1, v2) {
-    same <- (v1 == v2) | (is.na(v1) & is.na(v2))
-    same[is.na(same)] <- FALSE
-    return(same)
-  }
-
-  expect_true(all(compareNA(sort(cohortCensorDate %>%
-                                   dplyr::select(status) %>%
+  expect_true(all(compareNA(sort(cohortCensorDate |>
+                                   dplyr::select(status) |>
                                    dplyr::pull()),
                             sort(c(NA, 1, 0)))))
-  expect_true(all(compareNA(sort(cohortCensorDate %>%
-                                   dplyr::select(days_to_exit) %>%
+  expect_true(all(compareNA(sort(cohortCensorDate |>
+                                   dplyr::select(days_to_exit) |>
                                    dplyr::pull()),
                             sort(c(369, 368, 3)))))
-  expect_true(all(compareNA(sort(cohortCensorDate %>%
-                                   dplyr::select(time) %>%
+  expect_true(all(compareNA(sort(cohortCensorDate |>
+                                   dplyr::select(time) |>
                                    dplyr::pull()),
                             sort(c(NA, 3, 3)))))
 
   expect_error(
-    cdm$cohort1 %>%
+    cdm$cohort1 |>
       addCohortSurvival(
         cdm = cdm,
         outcomeCohortTable = "cohort2",
@@ -415,47 +404,47 @@ test_that("followUpDays", {
     cdmName = "mock_es"
   )
 
-  cohortFollowUp <- cdm$cohort1 %>%
+  cohortFollowUp <- cdm$cohort1 |>
     addCohortSurvival(
       cdm = cdm,
       outcomeCohortTable = "cohort2",
       outcomeCohortId = 1,
       followUp = 20
-    ) %>%
+    ) |>
     dplyr::arrange(subject_id)
-  cohortFUandCE <- cdm$cohort1 %>%
+  cohortFUandCE <- cdm$cohort1 |>
     addCohortSurvival(
       cdm = cdm,
       outcomeCohortTable = "cohort2",
       outcomeCohortId = 1,
       followUp = 20,
       censorOnCohortExit = TRUE
-    ) %>%
+    ) |>
     dplyr::arrange(subject_id)
 
-  expect_true(all(cohortFollowUp %>%
-                    dplyr::select(days_to_exit) %>%
+  expect_true(all(cohortFollowUp |>
+                    dplyr::select(days_to_exit) |>
                     dplyr::pull() ==
                     c(20,20,20)))
-  expect_true(all(cohortFollowUp %>%
-                    dplyr::select(status) %>%
+  expect_true(all(cohortFollowUp |>
+                    dplyr::select(status) |>
                     dplyr::pull() ==
                     c(0,1,1)))
-  expect_true(all(cohortFollowUp %>%
-                    dplyr::select(time) %>%
+  expect_true(all(cohortFollowUp |>
+                    dplyr::select(time) |>
                     dplyr::pull() ==
                     c(20,3,10)))
 
-  expect_true(all(cohortFUandCE %>%
-                    dplyr::select(days_to_exit) %>%
+  expect_true(all(cohortFUandCE |>
+                    dplyr::select(days_to_exit) |>
                     dplyr::pull() ==
                     c(20,20,5)))
-  expect_true(all(cohortFUandCE %>%
-                    dplyr::select(status) %>%
+  expect_true(all(cohortFUandCE |>
+                    dplyr::select(status) |>
                     dplyr::pull() ==
                     c(0,1,0)))
-  expect_true(all(cohortFUandCE %>%
-                    dplyr::select(time) %>%
+  expect_true(all(cohortFUandCE |>
+                    dplyr::select(time) |>
                     dplyr::pull() ==
                     c(20,3,5)))
 
@@ -468,21 +457,21 @@ test_that("expected errors", {
 
   # check outcome cohort
   # id that is not in the table
-  expect_error(cdm$mgus_diagnosis %>%
+  expect_error(cdm$mgus_diagnosis |>
                  addCohortSurvival(
                    cdm = cdm,
                    outcomeCohortTable = "death_cohort",
                    outcomeCohortId = 2
                  ))
   # should only work for one cohort
-  expect_error(cdm$mgus_diagnosis %>%
+  expect_error(cdm$mgus_diagnosis |>
                  addCohortSurvival(
                    cdm = cdm,
                    outcomeCohortTable = "death_cohort",
                    outcomeCohortId = c(1, 2)
                  ))
   # user must provide a cohort id
-  expect_error(cdm$mgus_diagnosis %>%
+  expect_error(cdm$mgus_diagnosis |>
                  addCohortSurvival(
                    cdm = cdm,
                    outcomeCohortTable = "death_cohort",
@@ -490,7 +479,7 @@ test_that("expected errors", {
                  ))
 
   # censorOnCohortExit must be logical
-  expect_error(cdm$mgus_diagnosis %>%
+  expect_error(cdm$mgus_diagnosis |>
                  addCohortSurvival(
                    cdm = cdm,
                    outcomeCohortTable = "death_cohort",
@@ -499,7 +488,7 @@ test_that("expected errors", {
                  ))
 
   # followUpDays must be 1 or higher
-  expect_error(cdm$mgus_diagnosis %>%
+  expect_error(cdm$mgus_diagnosis |>
                  addCohortSurvival(
                    cdm = cdm,
                    outcomeCohortTable = "death_cohort",
@@ -507,7 +496,7 @@ test_that("expected errors", {
                    followUpDays = -1
                  ))
 
-  expect_error(cdm$mgus_diagnosis %>%
+  expect_error(cdm$mgus_diagnosis |>
                  addCohortSurvival(
                    cdm = cdm,
                    outcomeCohortTable = "death_cohort",
@@ -516,7 +505,7 @@ test_that("expected errors", {
                  ))
 
   # temporary must be logical
-  expect_error(cdm$mgus_diagnosis %>%
+  expect_error(cdm$mgus_diagnosis |>
                  addCohortSurvival(
                    cdm = cdm,
                    outcomeCohortTable = "death_cohort",
@@ -524,7 +513,7 @@ test_that("expected errors", {
                    temporary = "maybe"
                  ))
 
-  expect_error(cdm$mgus_diagnosis %>%
+  expect_error(cdm$mgus_diagnosis |>
                  addCohortSurvival(
                    cdm = cdm,
                    outcomeCohortTable = "death_cohort",
@@ -533,12 +522,12 @@ test_that("expected errors", {
                  ))
 
     cdm <- PatientProfiles::mockPatientProfiles()
-    cdm[["cohort1"]] <- cdm[["cohort1"]] %>%
-      dplyr::group_by(subject_id) %>%
+    cdm[["cohort1"]] <- cdm[["cohort1"]] |>
+      dplyr::group_by(subject_id) |>
       dplyr::filter(dplyr::row_number() == 1)
 
   # multiple cohort definition ids in exposure table
-    expect_error(cdm$cohort1 %>%
+    expect_error(cdm$cohort1 |>
                    addCohortSurvival(
                      cdm = cdm,
                      outcomeCohortTable = "cohort1",
@@ -596,19 +585,19 @@ test_that("within cohort survival", {
 
   # default "cohort_start_date"
   # if using the same cohort, status would be 1, time would be 0 for everyone
-  cdm$cohort1_start <- cdm$cohort1 %>%
+  cdm$cohort1_start <- cdm$cohort1 |>
     addCohortSurvival(
       cdm = cdm,
       outcomeCohortTable = "cohort1",
       outcomeCohortId = 1,
       outcomeDateVariable = "cohort_start_date"
     )
-  expect_true(all(cdm$cohort1_start %>%
+  expect_true(all(cdm$cohort1_start |>
                     dplyr::pull("time") == 0))
-  expect_true(all(cdm$cohort1_start %>%
+  expect_true(all(cdm$cohort1_start |>
                     dplyr::pull("status") == 1))
 
-  cdm$cohort1_end <- cdm$cohort1 %>%
+  cdm$cohort1_end <- cdm$cohort1 |>
     addCohortSurvival(
       cdm = cdm,
       outcomeCohortTable = "cohort1",
@@ -616,15 +605,15 @@ test_that("within cohort survival", {
       outcomeDateVariable = "cohort_end_date"
     )
 
-  expect_true(all(cdm$cohort1_end %>%
-                    dplyr::collect() %>%
+  expect_true(all(cdm$cohort1_end |>
+                    dplyr::collect() |>
                     dplyr::mutate(dtime = as.numeric(difftime(cohort_end_date,
                                                               cohort_start_date)),
-                                  equal = (dtime == time)) %>%
+                                  equal = (dtime == time)) |>
                     dplyr::pull("equal")))
 
   # limit follow up
-  cdm$cohort1_b <- cdm$cohort1 %>%
+  cdm$cohort1_b <- cdm$cohort1 |>
     addCohortSurvival(
       cdm = cdm,
       outcomeCohortTable = "cohort1",
@@ -632,9 +621,9 @@ test_that("within cohort survival", {
       outcomeDateVariable = "cohort_end_date",
       followUpDays = 100
     )
-  expect_true(all(cdm$cohort1_b %>%
+  expect_true(all(cdm$cohort1_b |>
                     dplyr::pull("time") == c(91,100,100)))
-  expect_true(all(cdm$cohort1_b %>%
+  expect_true(all(cdm$cohort1_b |>
                     dplyr::pull("status") == c(1,0,0)))
 
   CDMConnector::cdmDisconnect(cdm)
@@ -686,22 +675,22 @@ test_that("allow overwrite of time and status", {
     cdmName = "mock_es"
   )
 
-  cdm$cohort1 <- cdm$cohort1 %>%
+  cdm$cohort1 <- cdm$cohort1 |>
     addCohortSurvival(
       cdm = cdm,
       outcomeCohortTable = "cohort1",
     )
 
-  cohort1_count <- cdm$cohort1 %>%
-    dplyr::group_by(.data$cohort_definition_id) %>%
+  cohort1_count <- cdm$cohort1 |>
+    dplyr::group_by(.data$cohort_definition_id) |>
     dplyr::summarise(
       number_records = dplyr::n(),
       number_subjects = dplyr::n_distinct(.data$subject_id),
       .groups = "drop"
     )
-  cohort1_set <- cdm$cohort1 %>%
-    dplyr::select("cohort_definition_id") %>%
-    dplyr::distinct() %>%
+  cohort1_set <- cdm$cohort1 |>
+    dplyr::select("cohort_definition_id") |>
+    dplyr::distinct() |>
     dplyr::mutate(cohort_name = "cohort1")
 
   # currently need to add attribute back to rerun
@@ -709,7 +698,7 @@ test_that("allow overwrite of time and status", {
   attr(cdm$cohort1, "count") <- cohort1_count
   attr(cdm$cohort1, "tbl_name") <- "cohort1"
 
-  cdm$cohort1 <- cdm$cohort1 %>%
+  cdm$cohort1 <- cdm$cohort1 |>
     addCohortSurvival(
       cdm = cdm,
       outcomeCohortTable = "cohort1",
@@ -791,32 +780,120 @@ test_that("multiple records per person", {
     cdmName = "mock_es"
   )
 
-  start_rows<-cdm$exposure_cohort %>% dplyr::count() %>% dplyr::pull()
+  start_rows<-cdm$exposure_cohort |> dplyr::count() |> dplyr::pull()
 
-  cdm$exposure_cohort <- cdm$exposure_cohort %>%
+  cdm$exposure_cohort <- cdm$exposure_cohort |>
     addCohortSurvival(cdm = cdm,
                       outcomeCohortTable = "cohort1")
 
-  end_rows <- cdm$exposure_cohort %>% dplyr::count() %>% dplyr::pull()
+  end_rows <- cdm$exposure_cohort |> dplyr::count() |> dplyr::pull()
   expect_equal(start_rows, end_rows)
 
-  expect_true(cdm$exposure_cohort %>%
+  expect_true(cdm$exposure_cohort |>
                 dplyr::filter(subject_id == 1,
-                              cohort_start_date == as.Date("2010-01-01")) %>%
+                              cohort_start_date == as.Date("2010-01-01")) |>
                 dplyr::pull("status") == 1)
   # NA for the second as their cohort start was after their event
-  expect_true(is.na(cdm$exposure_cohort %>%
+  expect_true(is.na(cdm$exposure_cohort |>
                       dplyr::filter(subject_id == 1,
-                                    cohort_start_date == as.Date("2015-01-01")) %>%
+                                    cohort_start_date == as.Date("2015-01-01")) |>
                       dplyr::pull("status")))
   # Both will be status == 1 as event came after second cohort entry
-  expect_true(all(cdm$exposure_cohort %>%
-                    dplyr::filter(subject_id == 2) %>%
+  expect_true(all(cdm$exposure_cohort |>
+                    dplyr::filter(subject_id == 2) |>
                     dplyr::pull("status") == 1))
   # no event for subject 3
-  expect_true(cdm$exposure_cohort %>%
-                dplyr::filter(subject_id == 3) %>%
+  expect_true(cdm$exposure_cohort |>
+                dplyr::filter(subject_id == 3) |>
                 dplyr::pull("status") == 0)
 
   CDMConnector::cdmDisconnect(cdm)
 })
+
+test_that("cohort id or cohort name", {
+  db <- DBI::dbConnect(duckdb::duckdb(), ":memory:")
+
+  cohort <- dplyr::tibble(
+    cohort_definition_id = c(1,1,1),
+    subject_id = c(1,2,3),
+    cohort_start_date = c(as.Date("2020-01-01"),
+                          as.Date("2020-01-02"),
+                          as.Date("2021-01-01")),
+    cohort_end_date = c(as.Date("2020-04-01"),
+                        as.Date("2020-08-02"),
+                        as.Date("2021-03-01"))
+  )
+  events <- dplyr::tibble(
+    cohort_definition_id = c(1,2,1),
+    subject_id = c(1,2,3),
+    cohort_start_date = c(as.Date("2019-01-01"),
+                          as.Date("2020-01-05"),
+                          as.Date("2021-02-01")),
+    cohort_end_date = c(as.Date("2019-01-01"),
+                        as.Date("2020-01-05"),
+                        as.Date("2021-02-01")),
+  )
+  observation_period <- dplyr::tibble(
+    observation_period_id = c(1,1,1),
+    person_id = c(1,2,3),
+    observation_period_start_date = c(as.Date("2000-01-01"),
+                                      as.Date("2000-01-02"),
+                                      as.Date("2000-01-01")),
+    observation_period_end_date = c(as.Date("2023-04-01"),
+                                    as.Date("2023-05-02"),
+                                    as.Date("2023-03-01")),
+    period_type_concept_id = c(rep(0,3))
+  )
+  person <- dplyr::tibble(
+    person_id = c(1, 2, 3, 4, 5),
+    year_of_birth = c(rep(1990, 5)),
+    month_of_birth = c(rep(2, 5)),
+    day_of_birth = c(rep(11, 5)),
+    gender_concept_id = c(rep(0,5)),
+    ethnicity_concept_id = c(rep(0,5)),
+    race_concept_id = c(rep(0,5))
+  )
+
+  cdm <- mockCohortSurvival(
+    tables = list(
+      person = person,
+      observation_period = observation_period
+    ),
+    cohortTables = list(
+      cohort1 = cohort,
+      cohort2 = events
+    ),
+    cdmName = "mock_es"
+  )
+
+  add_num <- cdm$cohort1 |>
+    addCohortSurvival(
+      cdm = cdm,
+      outcomeCohortTable = "cohort2",
+      outcomeCohortId = 1,
+      outcomeWashout = 0
+    )
+
+  add_name <- cdm$cohort1 |>
+    addCohortSurvival(
+      cdm = cdm,
+      outcomeCohortTable = "cohort2",
+      outcomeCohortId = "cohort_1",
+      outcomeWashout = 0
+    )
+
+  expect_equal(add_num |>
+                 dplyr::arrange(subject_id) |>
+                 dplyr::pull(status),
+               add_name |>
+                 dplyr::arrange(subject_id) |>
+                 dplyr::pull(status))
+
+  expect_equal(add_num |>
+                 dplyr::arrange(subject_id) |>
+                 dplyr::pull(time),
+               add_name |>
+                 dplyr::arrange(subject_id) |>
+                 dplyr::pull(time))
+CDMConnector::cdmDisconnect(cdm)
+})
